@@ -1,8 +1,10 @@
+#![recursion_limit = "256"]
+use test_log::test;
 use workspaces::prelude::*;
 
-#[tokio::test]
+#[test(tokio::test)]
 async fn test_subaccount_creation() -> anyhow::Result<()> {
-    let worker = workspaces::sandbox();
+    let worker = workspaces::sandbox().await?;
     let account = worker.dev_create_account().await?;
 
     let sub = account
